@@ -12,13 +12,16 @@ use crate::STATS;
 use crate::STORE;
 use anyhow::Result;
 use async_trait::async_trait;
+use axum::extract::ws::WebSocketUpgrade;
 use axum::response::Html;
-use axum::ws::ws;
 use axum::{
-    extract::{connect_info::ConnectInfo, extractor_middleware, RequestParts},
-    prelude::*,
+    extract::{self, connect_info::ConnectInfo, extractor_middleware, RequestParts},
+    handler::{get, post},
+    Router,
 };
 use bp7::dtntime::CreationTimestamp;
+use bp7::flags::BlockControlFlags;
+use bp7::flags::BundleControlFlags;
 use bp7::helpers::rnd_bundle;
 use bp7::EndpointID;
 use http::StatusCode;
@@ -333,10 +336,10 @@ async fn send_post(
         return Err((StatusCode::BAD_REQUEST, "Missing destination endpoint id!"));
     }
     let src = (*CONFIG.lock()).host_eid.clone();
+    let flags = BundleControlFlags::BUNDLE_MUST_NOT_FRAGMENTED
+        | BundleControlFlags::BUNDLE_STATUS_REQUEST_DELIVERY;
     let pblock = bp7::primary::PrimaryBlockBuilder::default()
-        .bundle_control_flags(
-            bp7::bundle::BUNDLE_MUST_NOT_FRAGMENTED | bp7::bundle::BUNDLE_STATUS_REQUEST_DELIVERY,
-        )
+        .bundle_control_flags(flags.bits())
         .destination(dst)
         .source(src.clone())
         .report_to(src)
@@ -352,8 +355,8 @@ async fn send_post(
     let mut bndl = bp7::bundle::BundleBuilder::default()
         .primary(pblock)
         .canonicals(vec![
-            bp7::canonical::new_payload_block(0, bytes.to_vec()),
-            bp7::canonical::new_hop_count_block(2, 0, 32),
+            bp7::canonical::new_payload_block(BlockControlFlags::empty(), bytes.to_vec()),
+            bp7::canonical::new_hop_count_block(2, BlockControlFlags::empty(), 32),
         ])
         .build()
         .unwrap();
@@ -566,14 +569,18 @@ async fn download_hex(
 }
 
 pub async fn spawn_httpd() -> Result<()> {
-    let app_local_only = route("/send", post(send_post))
+    let app_local_only = Router::new()
+        .route("/send", post(send_post))
         .route("/register", get(register))
         .route("/unregister", get(unregister))
         .route("/endpoint", get(endpoint))
         .route("/insert", get(insert_get).post(insert_post))
         .route("/endpoint.hex", get(endpoint_hex))
         .route("/cts", get(get_creation_timestamp))
-        .route("/ws", ws(super::ws::handle_socket))
+        .route(
+            "/ws",
+            get(|ws: WebSocketUpgrade| async move { ws.on_upgrade(super::ws::handle_socket) }),
+        )
         .route("/debug/rnd_bundle", get(debug_rnd_bundle))
         .route("/debug/rnd_peer", get(debug_rnd_peer))
         .layer(extractor_middleware::<RequireLocalhost>());
